@@ -132,6 +132,9 @@ aclIpAddrNetworkCompare(acl_ip_data * const &p, acl_ip_data * const &q)
     /* apply netmask */
     A.ApplyMask(q->mask);
 
+    debugs(28,9, "aclIpAddrNetworkCompare: compare: " << p->addr1 << "/" << q->mask << " (" << A << ")  vs " <<
+                 q->addr1 << "-" << q->addr2 << "/" << q->mask);
+
     if (q->addr2.IsAnyAddr()) {       /* single address check */
 
         return A.matchIPAddr( q->addr1 );
@@ -212,8 +215,24 @@ acl_ip_data::DecodeMask(const char *asc, IpAddress &mask, int ctype)
 
     /* dotted notation */
     /* assignment returns true if asc contained an IP address as text */
-    if ((mask = asc))
+    if ((mask = asc)) {
+#if USE_IPV6
+        /* HACK: IPv4 netmasks don't cleanly map to IPv6 masks. */
+        debugs(28, DBG_IMPORTANT, "WARNING: Netmasks are deprecated. Please use CIDR masks instead.");
+        if(mask.IsIPv4()) {
+            /* locate what CIDR mask was _probably_ meant to be in its native protocol format. */
+            /* this will completely crap out with a security fail-open if the admin is playing mask tricks */
+            /* however, thats their fault, and we do warn. see bug 2601 for the effects if we don't do this. */
+            unsigned int m = mask.GetCIDR();
+            debugs(28, DBG_CRITICAL, "WARNING: IPv4 netmasks are particularly nasty when used to compare IPv6 to IPv4 ranges.");
+            debugs(28, DBG_CRITICAL, "WARNING: For now we assume you meant to write /" << m);
+            /* reset the mask completely, and crop to the CIDR boundary back properly. */
+            mask.SetNoAddr();
+            return mask.ApplyMask(m,AF_INET);
+        }
+#endif /* USE_IPV6 */
         return true;
+    }
 
     return false;
 }
