@@ -1,5 +1,5 @@
 /*
- * $Id: auth_basic.cc,v 1.53 2008/02/12 23:17:50 rousskov Exp $
+ * $Id$
  *
  * DEBUG: section 29    Authenticator
  * AUTHOR: Duane Wessels
@@ -331,7 +331,7 @@ AuthBasicConfig::parse(AuthConfig * scheme, int n_configured, char *param_str)
 
         parse_wordlist(&authenticate);
 
-        requirePathnameExists("authparam basic program", authenticate->key);
+        requirePathnameExists("auth_param basic program", authenticate->key);
     } else if (strcasecmp(param_str, "children") == 0) {
         parse_int(&authenticateChildren);
     } else if (strcasecmp(param_str, "concurrency") == 0) {
