@@ -1,7 +1,4 @@
 /*
- * $Id: structs.h,v 1.575 2008/02/11 22:28:47 rousskov Exp $
- *
- *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
  * ----------------------------------------------------------
  *
@@ -18,12 +15,12 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
- *  
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
@@ -41,14 +38,12 @@
 /* needed for the global config */
 #include "HttpHeader.h"
 
-struct acl_name_list
-{
+struct acl_name_list {
     char name[ACL_NAME_SZ];
     acl_name_list *next;
 };
 
-struct acl_deny_info_list
-{
+struct acl_deny_info_list {
     err_type err_page_id;
     char *err_page_name;
     acl_name_list *acl_list;
@@ -58,8 +53,7 @@ struct acl_deny_info_list
 
 class acl_access;
 
-struct _header_mangler
-{
+struct _header_mangler {
     acl_access *access_list;
     char *replacement;
 };
@@ -68,8 +62,7 @@ class ACLChecklist;
 
 #if SQUID_SNMP
 
-struct _snmp_request_t
-{
+struct _snmp_request_t {
     u_char *buf;
     u_char *outbuf;
     int len;
@@ -77,7 +70,7 @@ struct _snmp_request_t
     long reqid;
     int outlen;
 
-    IPAddress from;
+    IpAddress from;
 
     struct snmp_pdu *PDU;
     ACLChecklist *acl_checklist;
@@ -90,36 +83,31 @@ struct _snmp_request_t
 
 class ACLList;
 
-struct acl_address
-{
+struct acl_address {
     acl_address *next;
     ACLList *aclList;
 
-    IPAddress addr;
+    IpAddress addr;
 };
 
-struct acl_tos
-{
+struct acl_tos {
     acl_tos *next;
     ACLList *aclList;
     int tos;
 };
 
-struct acl_size_t
-{
+struct acl_size_t {
     acl_size_t *next;
     ACLList *aclList;
     int64_t size;
 };
 
-struct ushortlist
-{
+struct ushortlist {
     u_short i;
     ushortlist *next;
 };
 
-struct relist
-{
+struct relist {
     char *pattern;
     regex_t regex;
     relist *next;
@@ -133,17 +121,19 @@ struct relist
 #include "icmp/IcmpConfig.h"
 #endif
 
+#if USE_ZPH_QOS
+#include "ip/QosConfig.h"
+#endif
+
 /* forward decl for SquidConfig, see RemovalPolicy.h */
 
 class RemovalPolicySettings;
 class external_acl;
 class Store;
 
-struct SquidConfig
-{
+struct SquidConfig {
 
-    struct
-    {
+    struct {
         /* These should be for the Store::Root instance.
         * this needs pluggable parsing to be done smoothly.
         */
@@ -152,8 +142,7 @@ struct SquidConfig
     } Swap;
     size_t memMaxSize;
 
-    struct
-    {
+    struct {
         int64_t min;
         int pct;
         int64_t max;
@@ -169,8 +158,7 @@ struct SquidConfig
     time_t shutdownLifetime;
     time_t backgroundPingRate;
 
-    struct
-    {
+    struct {
         time_t read;
         time_t lifetime;
         time_t connect;
@@ -201,8 +189,7 @@ struct SquidConfig
     size_t maxReplyHeaderSize;
     acl_size_t *ReplyBodySize;
 
-    struct
-    {
+    struct {
         u_short icp;
 #if USE_HTCP
 
@@ -214,8 +201,7 @@ struct SquidConfig
 #endif
     } Port;
 
-    struct
-    {
+    struct {
         http_port_list *http;
 #if USE_SSL
 
@@ -225,30 +211,27 @@ struct SquidConfig
     } Sockaddr;
 #if SQUID_SNMP
 
-    struct
-    {
+    struct {
         char *configFile;
         char *agentInfo;
     } Snmp;
 #endif
 #if USE_WCCP
 
-    struct
-    {
+    struct {
 
-        IPAddress router;
+        IpAddress router;
 
-        IPAddress address;
+        IpAddress address;
         int version;
     } Wccp;
 #endif
 #if USE_WCCPv2
 
-    struct
-    {
-        IPAddress_list *router;
+    struct {
+        IpAddress_list *router;
 
-        IPAddress address;
+        IpAddress address;
         int forwarding_method;
         int return_method;
         int assignment_method;
@@ -264,8 +247,7 @@ struct SquidConfig
 
     char *as_whois_server;
 
-    struct
-    {
+    struct {
         char *log;
         char *store;
         char *swap;
@@ -295,8 +277,7 @@ struct SquidConfig
     char *visible_appname_string;
     char *effectiveGroup;
 
-    struct
-    {
+    struct {
 #if USE_DNSSERVERS
         char *dnsserver;
 #endif
@@ -325,8 +306,7 @@ struct SquidConfig
     time_t authenticateTTL;
     time_t authenticateIpTTL;
 
-    struct
-    {
+    struct {
 #if USE_SQUID_ESI
         char *surrogate_id;
 #endif
@@ -344,28 +324,26 @@ struct SquidConfig
     wordlist *hostnameAliases;
     char *errHtmlText;
 
-    struct
-    {
+    struct {
         char *host;
         char *file;
         time_t period;
         u_short port;
     } Announce;
 
-    struct
-    {
+    struct {
 
-        IPAddress udp_incoming;
+        IpAddress udp_incoming;
 
-        IPAddress udp_outgoing;
+        IpAddress udp_outgoing;
 #if SQUID_SNMP
 
-        IPAddress snmp_incoming;
+        IpAddress snmp_incoming;
 
-        IPAddress snmp_outgoing;
+        IpAddress snmp_outgoing;
 #endif
         /* FIXME INET6 : this should really be a CIDR value */
-        IPAddress client_netmask;
+        IpAddress client_netmask;
     } Addrs;
     size_t tcpRcvBufsz;
     size_t udpMaxHitObjsz;
@@ -375,23 +353,20 @@ struct SquidConfig
     peer *peers;
     int npeers;
 
-    struct
-    {
+    struct {
         int size;
         int low;
         int high;
     } ipcache;
 
-    struct
-    {
+    struct {
         int size;
     } fqdncache;
     int minDirectHops;
     int minDirectRtt;
     cachemgr_passwd *passwd_list;
 
-    struct
-    {
+    struct {
         int objectsPerBucket;
         int64_t avgObjectSize;
         int64_t maxObjectSize;
@@ -399,15 +374,13 @@ struct SquidConfig
         size_t maxInMemObjSize;
     } Store;
 
-    struct
-    {
+    struct {
         int high;
         int low;
         time_t period;
     } Netdb;
 
-    struct
-    {
+    struct {
         int log_udp;
         int res_defnames;
         int anonymizer;
@@ -471,17 +444,12 @@ struct SquidConfig
         int log_uses_indirect_client;
 #endif /* FOLLOW_X_FORWARDED_FOR */
 
-#if USE_ZPH_QOS
-        int zph_tos_parent;
-        int zph_preserve_miss_tos;
-#endif
         int WIN32_IpAddrChangeMonitor;
     } onoff;
 
     class ACL *aclList;
 
-    struct
-    {
+    struct {
         acl_access *http;
         acl_access *icp;
         acl_access *miss;
@@ -494,8 +462,9 @@ struct SquidConfig
 
         acl_access *snmp;
 #endif
-
+#if HTTP_VIOLATIONS
         acl_access *brokenPosts;
+#endif
 #if USE_IDENT
 
         acl_access *identLookup;
@@ -511,7 +480,7 @@ struct SquidConfig
         acl_access *htcp;
         acl_access *htcp_clr;
 #endif
-        
+
 #if USE_SSL
         acl_access *ssl_bump;
 #endif
@@ -523,8 +492,7 @@ struct SquidConfig
     acl_deny_info_list *denyInfoList;
     authConfig authConfiguration;
 
-    struct
-    {
+    struct {
         size_t list_width;
         int list_wrap;
         char *anon_user;
@@ -535,15 +503,13 @@ struct SquidConfig
     } Ftp;
     refresh_t *Refresh;
 
-    struct _cacheSwap
-    {
+    struct _cacheSwap {
         RefCount<class Store> *swapDirs;
         int n_allocated;
         int n_configured;
     } cacheSwap;
 
-    struct
-    {
+    struct {
         char *directory;
         int use_short_names;
     } icons;
@@ -554,14 +520,12 @@ struct SquidConfig
 #endif
     char *errorStylesheet;
 
-    struct
-    {
+    struct {
         int maxtries;
         int onerror;
     } retry;
 
-    struct
-    {
+    struct {
         size_t limit;
     } MemPools;
 #if DELAY_POOLS
@@ -569,8 +533,7 @@ struct SquidConfig
     DelayConfig Delay;
 #endif
 
-    struct
-    {
+    struct {
         int icp_average;
         int dns_average;
         int http_average;
@@ -583,10 +546,9 @@ struct SquidConfig
     int64_t rangeOffsetLimit;
 #if MULTICAST_MISS_STREAM
 
-    struct
-    {
+    struct {
 
-        IPAddress addr;
+        IpAddress addr;
         int ttl;
         unsigned short port;
         char *encode_key;
@@ -601,8 +563,7 @@ struct SquidConfig
     char *chroot_dir;
 #if USE_CACHE_DIGESTS
 
-    struct
-    {
+    struct {
         int bits_per_entry;
         time_t rebuild_period;
         time_t rewrite_period;
@@ -612,8 +573,7 @@ struct SquidConfig
 #endif
 #if USE_SSL
 
-    struct
-    {
+    struct {
         int unclean_shutdown;
         char *ssl_engine;
     } SSL;
@@ -621,8 +581,7 @@ struct SquidConfig
 
     wordlist *ext_methods;
 
-    struct
-    {
+    struct {
         int high_rptm;
         int high_pf;
         size_t high_memory;
@@ -631,15 +590,14 @@ struct SquidConfig
     int sleep_after_fork;	/* microseconds */
     time_t minimum_expiry_time;	/* seconds */
     external_acl *externalAclHelperList;
+
 #if USE_ZPH_QOS
-    int zph_tos_local;
-    int zph_tos_peer;
-    int zph_preserve_miss_tos_mask; 
+    QosConfig zph;
 #endif
+
 #if USE_SSL
 
-    struct
-    {
+    struct {
         char *cert;
         char *key;
         int version;
@@ -664,10 +622,8 @@ struct SquidConfig
 
 SQUIDCEXTERN SquidConfig Config;
 
-struct SquidConfig2
-{
-    struct
-    {
+struct SquidConfig2 {
+    struct {
         int enable_purge;
         int mangle_request_headers;
     } onoff;
@@ -677,15 +633,13 @@ struct SquidConfig2
 
 SQUIDCEXTERN SquidConfig2 Config2;
 
-struct _close_handler
-{
+struct _close_handler {
     PF *handler;
     void *data;
     close_handler *next;
 };
 
-struct _dread_ctrl
-{
+struct _dread_ctrl {
     int fd;
     off_t offset;
     int req_len;
@@ -695,8 +649,7 @@ struct _dread_ctrl
     void *client_data;
 };
 
-struct _dwrite_q
-{
+struct _dwrite_q {
     off_t file_offset;
     char *buf;
     size_t len;
@@ -711,14 +664,12 @@ struct _dwrite_q
  * Note: "str" points to memory in HttpHeaderEntry (for now)
  *       so ETags should be used as tmp variables only (for now) */
 
-struct _ETag
-{
+struct _ETag {
     const char *str;		/* quoted-string */
     int weak;			/* true if it is a weak validator */
 };
 
-struct _fde_disk
-{
+struct _fde_disk {
     DWCB *wrt_handle;
     void *wrt_handle_data;
     dwrite_q *write_q;
@@ -726,8 +677,7 @@ struct _fde_disk
     off_t offset;
 };
 
-struct _fileMap
-{
+struct _fileMap {
     int max_n_files;
     int n_files_in_map;
     int toggle;
@@ -742,8 +692,7 @@ struct _fileMap
 
 class MemBuf;
 
-struct _HttpBody
-{
+struct _HttpBody {
     /* private */
     MemBuf *mb;
 };
@@ -772,8 +721,7 @@ public:
 
 /* some fields can hold either time or etag specs (e.g. If-Range) */
 
-struct _TimeOrTag
-{
+struct _TimeOrTag {
     ETag tag;			/* entity tag */
     time_t time;
     int valid;			/* true if struct is usable */
@@ -785,7 +733,7 @@ class HttpHeaderFieldStat
 {
 
 public:
-    HttpHeaderFieldStat() : aliveCount(0), seenCount(0), parsCount(0), errCount(0), repCount(0){}
+    HttpHeaderFieldStat() : aliveCount(0), seenCount(0), parsCount(0), errCount(0), repCount(0) {}
 
     int aliveCount;		/* created but not destroyed (count) */
     int seenCount;		/* #fields we've seen */
@@ -800,7 +748,7 @@ class HttpHeaderFieldInfo
 {
 
 public:
-    HttpHeaderFieldInfo() : id (HDR_ACCEPT), type (ftInvalid){}
+    HttpHeaderFieldInfo() : id (HDR_ACCEPT), type (ftInvalid) {}
 
     http_hdr_type id;
     String name;
@@ -808,8 +756,7 @@ public:
     HttpHeaderFieldStat stat;
 };
 
-struct _http_state_flags
-{
+struct _http_state_flags {
     unsigned int proxying:1;
     unsigned int keepalive:1;
     unsigned int only_if_cached:1;
@@ -824,24 +771,21 @@ struct _http_state_flags
     unsigned int chunked:1;
 };
 
-struct _ipcache_addrs
-{
-    IPAddress *in_addrs;
+struct _ipcache_addrs {
+    IpAddress *in_addrs;
     unsigned char *bad_mask;
     unsigned char count;
     unsigned char cur;
     unsigned char badcount;
 };
 
-struct _domain_ping
-{
+struct _domain_ping {
     char *domain;
     int do_ping;		/* boolean */
     domain_ping *next;
 };
 
-struct _domain_type
-{
+struct _domain_type {
     char *domain;
     peer_t type;
     domain_type *next;
@@ -851,8 +795,7 @@ struct _domain_type
 
 /* statistics for cache digests and other hit "predictors" */
 
-struct _cd_guess_stats
-{
+struct _cd_guess_stats {
     /* public, read-only */
     int true_hits;
     int false_hits;
@@ -865,17 +808,15 @@ struct _cd_guess_stats
 
 class PeerDigest;
 
-struct peer
-{
+struct peer {
     u_int index;
     char *name;
     char *host;
     peer_t type;
 
-    IPAddress in_addr;
+    IpAddress in_addr;
 
-    struct
-    {
+    struct {
         int pings_sent;
         int pings_acked;
         int fetches;
@@ -892,16 +833,14 @@ struct peer
         int conn_open;		/* current opened connections */
     } stats;
 
-    struct
-    {
+    struct {
         int version;
         int counts[ICP_END+1];
         u_short port;
     } icp;
 #if USE_HTCP
 
-    struct
-    {
+    struct {
         double version;
         int counts[2];
         u_short port;
@@ -913,8 +852,7 @@ struct peer
     domain_type *typelist;
     acl_access *access;
 
-    struct
-    {
+    struct {
         unsigned int proxy_only:1;
         unsigned int no_query:1;
         unsigned int background_ping:1;
@@ -946,16 +884,14 @@ struct peer
     int weight;
     int basetime;
 
-    struct
-    {
+    struct {
         double avg_n_members;
         int n_times_counted;
         int n_replies_expected;
         int ttl;
         int id;
 
-        struct
-        {
+        struct {
             unsigned int count_event_pending:1;
             unsigned int counting:1;
         } flags;
@@ -968,28 +904,25 @@ struct peer
 
     int tcp_up;			/* 0 if a connect() fails */
 
-    IPAddress addresses[10];
+    IpAddress addresses[10];
     int n_addresses;
     int rr_count;
     peer *next;
     int test_fd;
 
-    struct
-    {
+    struct {
         unsigned int hash;
         double load_multiplier;
         double load_factor;	/* normalized weight value */
     } carp;
 
-    struct
-    {
+    struct {
         unsigned int hash;
         double load_multiplier;
         double load_factor;	/* normalized weight value */
     } userhash;
 
-    struct
-    {
+    struct {
         unsigned int hash;
         double load_multiplier;
         double load_factor;	/* normalized weight value */
@@ -1020,23 +953,20 @@ struct peer
     int connection_auth;
 };
 
-struct _net_db_name
-{
+struct _net_db_name {
     hash_link hash;		/* must be first */
     net_db_name *next;
     netdbEntry *net_db_entry;
 };
 
-struct _net_db_peer
-{
+struct _net_db_peer {
     const char *peername;
     double hops;
     double rtt;
     time_t expires;
 };
 
-struct _netdbEntry
-{
+struct _netdbEntry {
     hash_link hash;		/* must be first */
     char network[MAX_IPSTRLEN];
     int pings_sent;
@@ -1053,11 +983,9 @@ struct _netdbEntry
 };
 
 
-struct _iostats
-{
+struct _iostats {
 
-    struct
-    {
+    struct {
         int reads;
         int reads_deferred;
         int read_hist[16];
@@ -1069,15 +997,13 @@ struct _iostats
 };
 
 
-struct request_flags
-{
-    request_flags(): range(0),nocache(0),ims(0),auth(0),cachable(0),hierarchical(0),loopdetect(0),proxy_keepalive(0),proxying(0),refresh(0),redirected(0),need_validation(0),accelerated(0),intercepted(0),spoof_client_ip(0),internal(0),internalclient(0),must_keepalive(0),destinationIPLookedUp_(0)
-    {
+struct request_flags {
+    request_flags(): range(0),nocache(0),ims(0),auth(0),cachable(0),hierarchical(0),loopdetect(0),proxy_keepalive(0),proxying(0),refresh(0),redirected(0),need_validation(0),accelerated(0),intercepted(0),spoof_client_ip(0),internal(0),internalclient(0),must_keepalive(0),destinationIPLookedUp_(0) {
 #if HTTP_VIOLATIONS
         nocache_hack = 0;
 #endif
 #if FOLLOW_X_FORWARDED_FOR
-    done_follow_x_forwarded_for = 0;
+        done_follow_x_forwarded_for = 0;
 #endif /* FOLLOW_X_FORWARDED_FOR */
     }
 
@@ -1089,7 +1015,8 @@ struct request_flags
     unsigned int hierarchical:1;
     unsigned int loopdetect:1;
     unsigned int proxy_keepalive:1;
-    unsigned int proxying:1;	/* this should be killed, also in httpstateflags */
+unsigned int proxying:
+    1;	/* this should be killed, also in httpstateflags */
     unsigned int refresh:1;
     unsigned int redirected:1;
     unsigned int need_validation:1;
@@ -1129,22 +1056,19 @@ private:
     unsigned int destinationIPLookedUp_:1;
 };
 
-struct _link_list
-{
+struct _link_list {
     void *ptr;
 
     struct _link_list *next;
 };
 
-struct _cachemgr_passwd
-{
+struct _cachemgr_passwd {
     char *passwd;
     wordlist *actions;
     cachemgr_passwd *next;
 };
 
-struct _refresh_t
-{
+struct _refresh_t {
     const char *pattern;
     regex_t compiled_pattern;
     time_t min;
@@ -1152,8 +1076,7 @@ struct _refresh_t
     time_t max;
     refresh_t *next;
 
-    struct
-    {
+    struct {
         unsigned int icase:1;
         unsigned int refresh_ims:1;
 #if HTTP_VIOLATIONS
@@ -1170,12 +1093,11 @@ struct _refresh_t
 };
 
 /*
- * "very generic" histogram; 
+ * "very generic" histogram;
  * see important comments on hbase_f restrictions in StatHist.c
  */
 
-struct _StatHist
-{
+struct _StatHist {
     int *bins;
     int capacity;
     double min;
@@ -1186,15 +1108,13 @@ struct _StatHist
 };
 
 /*
- * if you add a field to StatCounters, 
+ * if you add a field to StatCounters,
  * you MUST sync statCountersInitSpecial, statCountersClean, and statCountersCopy
  */
 
-struct _StatCounters
-{
+struct _StatCounters {
 
-    struct
-    {
+    struct {
         int clients;
         int requests;
         int hits;
@@ -1211,11 +1131,9 @@ struct _StatCounters
         StatHist all_svc_time;
     } client_http;
 
-    struct
-    {
+    struct {
 
-        struct
-        {
+        struct {
             int requests;
             int errors;
             kb_t kbytes_in;
@@ -1223,8 +1141,7 @@ struct _StatCounters
         } all , http, ftp, other;
     } server;
 
-    struct
-    {
+    struct {
         int pkts_sent;
         int queries_sent;
         int replies_sent;
@@ -1247,24 +1164,20 @@ struct _StatCounters
         int times_used;
     } icp;
 
-    struct
-    {
+    struct {
         int pkts_sent;
         int pkts_recv;
     } htcp;
 
-    struct
-    {
+    struct {
         int requests;
     } unlink;
 
-    struct
-    {
+    struct {
         StatHist svc_time;
     } dns;
 
-    struct
-    {
+    struct {
         int times_used;
         kb_t kbytes_sent;
         kb_t kbytes_recv;
@@ -1279,8 +1192,7 @@ struct _StatCounters
         StatHist on_xition_count;
     } cd;
 
-    struct
-    {
+    struct {
         int times_used;
     } netdb;
     int page_faults;
@@ -1295,10 +1207,8 @@ struct _StatCounters
     StatHist comm_http_incoming;
     StatHist select_fds_hist;
 
-    struct
-    {
-        struct
-        {
+    struct {
+        struct {
             int opens;
             int closes;
             int reads;
@@ -1307,8 +1217,7 @@ struct _StatCounters
             int unlinks;
         } disk;
 
-        struct
-        {
+        struct {
             int accepts;
             int sockets;
             int connects;
@@ -1323,8 +1232,7 @@ struct _StatCounters
     } syscalls;
     int aborted_requests;
 
-    struct
-    {
+    struct {
         int files_cleaned;
         int outs;
         int ins;
@@ -1333,8 +1241,7 @@ struct _StatCounters
 
 /* per header statistics */
 
-struct _HttpHeaderStat
-{
+struct _HttpHeaderStat {
     const char *label;
     HttpHeaderMask *owner_mask;
 
@@ -1351,14 +1258,12 @@ struct _HttpHeaderStat
 };
 
 
-struct _ClientInfo
-{
+struct _ClientInfo {
     hash_link hash;		/* must be first */
 
-    IPAddress addr;
+    IpAddress addr;
 
-    struct
-    {
+    struct {
         int result_hist[LOG_TYPE_MAX];
         int n_requests;
         kb_t kbytes_in;
@@ -1366,8 +1271,7 @@ struct _ClientInfo
         kb_t hit_kbytes_out;
     } Http, Icp;
 
-    struct
-    {
+    struct {
         time_t time;
         int n_req;
         int n_denied;
@@ -1376,8 +1280,7 @@ struct _ClientInfo
     time_t last_seen;
 };
 
-struct _CacheDigest
-{
+struct _CacheDigest {
     /* public, read-only */
     char *mask;			/* bit mask */
     int mask_size;		/* mask size in bytes */
@@ -1388,8 +1291,7 @@ struct _CacheDigest
 };
 
 
-struct _store_rebuild_data
-{
+struct _store_rebuild_data {
     int objcount;		/* # objects successfully reloaded */
     int expcount;		/* # objects expired */
     int scancount;		/* # entries scanned or read from state file */
@@ -1402,16 +1304,14 @@ struct _store_rebuild_data
     int zero_object_sz;
 };
 
-struct _Logfile
-{
+struct _Logfile {
     int fd;
     char path[MAXPATHLEN];
     char *buf;
     size_t bufsz;
     size_t offset;
 
-    struct
-    {
+    struct {
         unsigned int fatal;
         unsigned int syslog;
     } flags;
@@ -1421,15 +1321,13 @@ struct _Logfile
 
 class logformat_token;
 
-struct _logformat
-{
+struct _logformat {
     char *name;
     logformat_token *format;
     logformat *next;
 };
 
-struct _customlog
-{
+struct _customlog {
     char *filename;
     ACLList *aclList;
     logformat *logFormat;
