@@ -263,8 +263,8 @@ TunnelStateData::Connection::error(int const xerrno)
     if (xerrno == COMM_ERR_CLOSING)
         return;
 
-    debugs(50, debugLevelForError(xerrno), "tunnelReadServer: FD " << fd() <<
-           ": read failure: " << xstrerror());
+    debugs(50, debugLevelForError(xerrno), "TunnelStateData::Connection::error: FD " << fd() <<
+           ": read/write failure: " << xstrerror());
 
     if (!ignoreErrno(xerrno))
         comm_close(fd());
@@ -613,9 +613,10 @@ tunnelStart(ClientHttpRequest * http, int64_t * size_ptr, int *status_ptr)
      * be allowed.  yuck, I know.
      */
 
-    if (!request->client_addr.IsNoAddr()) {
+    if (!request->client_addr.IsNoAddr() && Config.accessList.miss) {
         /*
          * Check if this host is allowed to fetch MISSES from us (miss_access)
+         * default is to allow.
          */
         ACLChecklist ch;
         ch.src_addr = request->client_addr;
